import { RemovalPolicy } from 'aws-cdk-lib';
import { IInterfaceVpcEndpoint, ISecurityGroup } from 'aws-cdk-lib/aws-ec2';
import { Role } from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { RedshiftDataProps } from './redshift-data-props';
import { TrackedConstruct } from '../../../../utils';
export interface RedshiftDataAccessTargetProps {
    readonly targetArn: string;
    readonly targetType: 'provisioned' | 'serverless';
    readonly targetId: string;
}
export declare abstract class BaseRedshiftDataAccess extends TrackedConstruct {
    /**
     * The Security Group used by the Custom Resource when deployed in a VPC
     */
    readonly customResourceSecurityGroup?: ISecurityGroup;
    /**
     * The Security Group used by the VPC Endpoint when deployed in a VPC
     */
    readonly vpcEndpointSecurityGroup?: ISecurityGroup;
    /**
     * The created Redshift Data API interface vpc endpoint when deployed in a VPC
     */
    readonly vpcEndpoint?: IInterfaceVpcEndpoint;
    protected readonly removalPolicy: RemovalPolicy;
    constructor(scope: Construct, id: string, props: RedshiftDataProps, trackedConstructProps: any);
    protected getDataAccessTarget(props: RedshiftDataProps): RedshiftDataAccessTargetProps;
    protected createProviderExecutionRole(id: string, dataAccessTarget: RedshiftDataAccessTargetProps, props: RedshiftDataProps): Role;
}
